cds containers: lfqueue and lfstack: don't depend on a particular rcu flavor
[urcu.git] / urcu.h
diff --git a/urcu.h b/urcu.h
index 69c06e409ddaf2bb95d96d27ae6d9369b777d40b..15c8c3897f13072fd607c6c97a7cb188b0f14b87 100644 (file)
--- a/urcu.h
+++ b/urcu.h
@@ -6,7 +6,7 @@
  *
  * Userspace RCU header
  *
- * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
+ * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  * Copyright (c) 2009 Paul E. McKenney, IBM Corporation.
  *
  * LGPL-compatible code should include this header with :
  */
 #include <urcu-pointer.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif 
+
+#include "urcu-map.h"
+
 /*
  * Important !
  *
  * Each thread containing read-side critical sections must be registered
- * with rcu_register_thread() before calling rcu_read_lock().
- * rcu_unregister_thread() should be called before the thread exits.
+ * with rcu_register_thread_mb() before calling rcu_read_lock_mb().
+ * rcu_unregister_thread_mb() should be called before the thread exits.
  */
 
 #ifdef _LGPL_SOURCE
  * DON'T FORGET TO USE RCU_REGISTER/UNREGISTER_THREAD() FOR EACH THREAD WITH
  * READ-SIDE CRITICAL SECTION.
  */
-#define rcu_read_lock()                _rcu_read_lock()
-#define rcu_read_unlock()      _rcu_read_unlock()
+#ifdef RCU_MEMBARRIER
+#define rcu_read_lock_memb             _rcu_read_lock
+#define rcu_read_unlock_memb           _rcu_read_unlock
+#elif defined(RCU_SIGNAL)
+#define rcu_read_lock_sig              _rcu_read_lock
+#define rcu_read_unlock_sig            _rcu_read_unlock
+#elif defined(RCU_MB)
+#define rcu_read_lock_mb               _rcu_read_lock
+#define rcu_read_unlock_mb             _rcu_read_unlock
+#endif
 
 #else /* !_LGPL_SOURCE */
 
@@ -88,8 +102,15 @@ extern void rcu_register_thread(void);
 extern void rcu_unregister_thread(void);
 
 /*
* Explicit urcu initialization, for "early" use within library constructors.
  */
-extern void urcu_init(void);
+extern void rcu_init(void);
+
+#ifdef __cplusplus 
+}
+#endif
+
+#include "urcu-call-rcu.h"
+#include "urcu-defer.h"
 
 #endif /* _URCU_H */
This page took 0.023308 seconds and 4 git commands to generate.
@@ -88,8 +102,15 @@ extern void rcu_register_thread(void);
 
 /*
- * Explicit urcu initialization, for "early" use within library constructors.
+ * Explicit rcu initialization, for "early" use within library constructors.
  */